/*
ChatRoomEphemeralMode.java
Copyright (C) 2010  Belledonne Communications, Grenoble, France

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.linphone.core;

import androidx.annotation.Nullable;
import androidx.annotation.NonNull;

/**
* {@link ChatRoomEphemeralMode} is used to the ephemeral message mode used by a<br/>
* chat room. <br/>
* <br/>
*/
public enum ChatRoomEphemeralMode {
    /**
    * Each device manages its own ephemeral settings. <br/>
    * <br/>
    */
    DeviceManaged(0),

    /**
    * Ephemeral settings are chatroom wide and only admins can change them. <br/>
    * <br/>
    */
    AdminManaged(1);

    protected final int mValue;

    private ChatRoomEphemeralMode (int value) {
        mValue = value;
    }

    static public ChatRoomEphemeralMode fromInt(int value) throws RuntimeException {
        switch(value) {
        case 0: return DeviceManaged;
        case 1: return AdminManaged;
        default:
            throw new RuntimeException("Unhandled enum value " + value + " for ChatRoomEphemeralMode");
        }
    }

    public int toInt() {
        return mValue;
    }
}
