/*
LdapCertVerificationMode.java
Copyright (C) 2010  Belledonne Communications, Grenoble, France

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.linphone.core;

import androidx.annotation.Nullable;
import androidx.annotation.NonNull;

/**
* Enum describing server certificates verification modes. <br/>
* <br/>
*/
public enum LdapCertVerificationMode {
    /**
    * Use default value defined on core. <br/>
    * <br/>
    */
    Default(-1),

    /**
    * Verification is disabled. <br/>
    * <br/>
    */
    Disabled(0),

    /**
    * Verification is enabled. <br/>
    * <br/>
    */
    Enabled(1);

    protected final int mValue;

    private LdapCertVerificationMode (int value) {
        mValue = value;
    }

    static public LdapCertVerificationMode fromInt(int value) throws RuntimeException {
        switch(value) {
        case -1: return Default;
        case 0: return Disabled;
        case 1: return Enabled;
        default:
            throw new RuntimeException("Unhandled enum value " + value + " for LdapCertVerificationMode");
        }
    }

    public int toInt() {
        return mValue;
    }
}
